# Library for acctest acceptance tests done by ssh access to the target
# to be sourced at beginning of tests/acctest bash script
#
# 2007-08 PTX,JFR


RED='\0033[1;31m'
GREEN='\0033[1;32m'
NC='\0033[0m' # No Color
ok_count=0
fail_count=0

SSH_COMMAND='ssh -o StrictHostKeyChecking=no'

checking() {
        printf "%-71s" "checking $1" >&2
}

result_ok() {
        printf "%8b" "[${GREEN}  OK  ${NC}]\n" >&2
        (( ok_count++ ))
}

result_fail() {
        printf "%8b" "[${RED}FAILED${NC}]\n" >&2
        (( fail_count++ ))

}

result() {
        if [ "$?" = "0" ]; then
                printf "%8b" "[${GREEN}  OK  ${NC}]\n" >&2
                (( ok_count++ ))
        else
                printf "%8b" "[${RED}FAILED${NC}]\n" >&2
                (( fail_count++ ))
		if [ "$1" = "fatal" ]; then
			printf "%8b" "${RED}Fatal. Cannot continue.${NC}\n" >&2
			exit 1
		fi
        fi
}

#
# functions acting on target
#

remote() {
        echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} $1" >> "${PTXDIST_WORKSPACE}/test.log"
        $SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} $1 2>> "${PTXDIST_WORKSPACE}/test.log"
}


remote_compare() {
        echo "test \"\$\($SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} $1\)\" = \"$2\"" >> "${PTXDIST_WORKSPACE}/test.log"
        local ret=$($SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} $1) 2>> "${PTXDIST_WORKSPACE}/test.log"
        test "$ret" = "$2" 2>> "${PTXDIST_WORKSPACE}/test.log"
}

remote_assure_module() {
# this should not be used as an indicator for functionality:
# don't just check on loaded modules; rather check their indirect signs of operationality.
        echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} lsmod | grep \"^$1 \"" >> "${PTXDIST_WORKSPACE}/test.log"
        local ret=$($SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} lsmod | grep "^$1 ") 2>> "${PTXDIST_WORKSPACE}/test.log"
        test "${ret:0:${#1}}" = "$1" 2>> "${PTXDIST_WORKSPACE}/test.log"
}

remote_assure_process() {
        local bbtest=$($SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} ps --help 2>&1 | grep ^BusyBox) 2>> "${PTXDIST_WORKSPACE}/test.log"
        if [ "${bbtest:0:7}" = "BusyBox" ]
        then
                echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} ps | grep \"$1\" | grep -v grep" >> "${PTXDIST_WORKSPACE}/test.log"
                local ret=$($SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} ps | grep $1 | grep -v grep) 2>> "${PTXDIST_WORKSPACE}/test.log"
                echo "$ret" | grep "$1[$ ]" 2>> "${PTXDIST_WORKSPACE}/test.log"
        else
                echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} ps axo s,comm | grep \"^S $1\"" >> "${PTXDIST_WORKSPACE}/test.log"
                local ret=$($SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} ps axo s,comm | grep "^S $1") 2>> "${PTXDIST_WORKSPACE}/test.log"
                test "${ret:2:${#1}}" = "$1" 2>> "${PTXDIST_WORKSPACE}/test.log"
        fi
}

remote_file() {
        case "$2" in
        'block')
                echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -b \"$1\"" >> "${PTXDIST_WORKSPACE}/test.log"
                $SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -b "$1" 2>> "${PTXDIST_WORKSPACE}/test.log"
                ;;
        'character')
                echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -c \"$1\"" >> "${PTXDIST_WORKSPACE}/test.log"
                $SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -c "$1" 2>> "${PTXDIST_WORKSPACE}/test.log"
                ;;
        'exists')
                echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -e \"$1\"" >> "${PTXDIST_WORKSPACE}/test.log"
                $SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -e "$1" 2>> "${PTXDIST_WORKSPACE}/test.log"
                ;;
        'executable')
                echo "$SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -x \"$1\"" >> "${PTXDIST_WORKSPACE}/test.log"
                $SSH_COMMAND root@${PTXCONF_BOARDSETUP_TARGETIP} test -x "$1" 2>> "${PTXDIST_WORKSPACE}/test.log"
                ;;
        *)
                echo "Syntax error in test script $0" >> "${PTXDIST_WORKSPACE}/test.log"
                false
        esac
}

all_on_board() {
	checking "for sed on target"
	remote_file "/bin/sed" executable
	result fatal
	checking "for grep on target"
	remote_file "/bin/grep" executable
	result fatal
	checking "for regular ps on target"
	remote 'ps --help | grep "^-o"'
	result fatal
}
